@@ -43,9 +43,9 @@ CACredits::CACredits()
     text.push_back("- Beta Testing / Feedback -");
     text.push_back("");
     text.push_back("Martin Mustun, Michael Mustun,");
-    text.push_back("Chris Bruengger, Markus Krieter");
+    text.push_back("Chris Bruengger, Markus Krieter, Trevor Cordes");
     text.push_back("Armijn Hemel, Guus Sliepen, Alfred de Wijn");
-    text.push_back("Kenneth Gangstoe, Martin Starch Soerensen");
+    text.push_back("Kenneth Gangstoe, Martin Starch Soerensen");       
     text.push_back("");
     text.push_back("");
     text.push_back("- Graphics Library ClanLib -");
