@@ -4,7 +4,8 @@
 #include <ClanLib/core.h>
 #include <ClanLib/display.h>
 #include "cadialog.h"
-#include "castringlist.h"
+#include <vector>
+#include <string>
 
 /** Credits screen.
     @author Andrew Mustun
@@ -17,13 +18,15 @@ public:
     virtual void buildScreen();
     virtual void on_key_released( const CL_InputEvent &key );
 
+protected:
+    void setText(const std::vector<std::string>& newText);
+
 private:
     //! Position of scrolling text
-
-
     float scrollPos;
     //! The scrolling text
-    CAStringList text;
+    std::vector<std::string> text;
+    
 };
 
 #endif
