@@ -138,7 +138,11 @@ void
 CAResources::load() {
     // Try to load resource file (resources.dat):
     //
-    chdir(PKGDATADIR);
+    if (chdir(PKGDATADIR) != 0)
+    {
+        std::cout << "Using local ../resources/resources.xml" << std::endl;
+	// Note : CL_ResourceManager will fail and launch an exception that will be catched by trophy.cpp
+    }
 
     try {
         // TODO : Can we just forget the boolean ?
@@ -147,7 +151,6 @@ CAResources::load() {
     }
 
     // Just use the resource config file (resources.scr) if there's no compiled .dat:
-    //
     catch (CL_Error err) {
         // TODO : Can we just forget the boolean ?
         //resources = new CL_ResourceManager( "resources.scr", false );
