@@ -194,13 +194,24 @@ void
 Player::setDirection( float dir ) 
 {
     newDirection=dir;
-    if( newDirection >= 360.0 ) newDirection-=360.0;
-    if( newDirection <    0.0 ) newDirection+=360.0;
+    while( newDirection >= 360.0 ) newDirection-=360.0;
+    while( newDirection <    0.0 ) newDirection+=360.0;
 
     int newFrame = (int)(newDirection/360.0*CA_FPR);
     setFrame( newFrame );
 }
 
+void
+Player::setFrame( int f )
+{
+    frame=f; 
+    if (frame >= CA_FPR)
+        frame = CA_FPR - 1;
+    else if (frame < 0)
+        frame = 0;
+}
+
+
 /** Changes the speed of this sprite.
 */
 void
